@@ -19,13 +19,18 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.documentai_v1.types import document
@@ -183,17 +188,17 @@ class DocumentProcessorServiceAsyncClient:
 
     async def process_document(
         self,
-        request: document_processor_service.ProcessRequest = None,
+        request: Union[document_processor_service.ProcessRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> document_processor_service.ProcessResponse:
         r"""Processes a single document.
 
         Args:
-            request (:class:`google.cloud.documentai_v1.types.ProcessRequest`):
+            request (Union[google.cloud.documentai_v1.types.ProcessRequest, dict]):
                 The request object. Request message for the process
                 document method.
             name (:class:`str`):
@@ -264,10 +269,10 @@ class DocumentProcessorServiceAsyncClient:
 
     async def batch_process_documents(
         self,
-        request: document_processor_service.BatchProcessRequest = None,
+        request: Union[document_processor_service.BatchProcessRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -275,7 +280,7 @@ class DocumentProcessorServiceAsyncClient:
         written to Cloud Storage as JSON in the [Document] format.
 
         Args:
-            request (:class:`google.cloud.documentai_v1.types.BatchProcessRequest`):
+            request (Union[google.cloud.documentai_v1.types.BatchProcessRequest, dict]):
                 The request object. Request message for batch process
                 document method.
             name (:class:`str`):
@@ -357,10 +362,10 @@ class DocumentProcessorServiceAsyncClient:
 
     async def review_document(
         self,
-        request: document_processor_service.ReviewDocumentRequest = None,
+        request: Union[document_processor_service.ReviewDocumentRequest, dict] = None,
         *,
         human_review_config: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -368,7 +373,7 @@ class DocumentProcessorServiceAsyncClient:
         should be processed by the specified processor.
 
         Args:
-            request (:class:`google.cloud.documentai_v1.types.ReviewDocumentRequest`):
+            request (Union[google.cloud.documentai_v1.types.ReviewDocumentRequest, dict]):
                 The request object. Request message for review document
                 method.
             human_review_config (:class:`str`):
