@@ -314,10 +314,19 @@ class AutoMlParams(proto.Message):
 class InputConfig(proto.Message):
     r"""The desired input location and metadata.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         gcs_source (google.cloud.documentai_v1beta2.types.GcsSource):
             The Google Cloud Storage location to read the
             input from. This must be a single file.
+
+            This field is a member of `oneof`_ ``source``.
         contents (bytes):
             Content in bytes, represented as a stream of bytes. Note: As
             with all ``bytes`` fields, proto buffer messages use a pure
@@ -326,6 +335,8 @@ class InputConfig(proto.Message):
 
             This field only works for synchronous ProcessDocument
             method.
+
+            This field is a member of `oneof`_ ``source``.
         mime_type (str):
             Required. Mimetype of the input. Current supported mimetypes
             are application/pdf, image/tiff, and image/gif. In addition,
@@ -345,10 +356,14 @@ class InputConfig(proto.Message):
 class OutputConfig(proto.Message):
     r"""The desired output location and metadata.
 
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         gcs_destination (google.cloud.documentai_v1beta2.types.GcsDestination):
             The Google Cloud Storage location to write
             the output to.
+
+            This field is a member of `oneof`_ ``destination``.
         pages_per_shard (int):
             The max number of pages to include into each output Document
             shard JSON on Google Cloud Storage.
